system/renameutils: Added (file renaming utilities).

Signed-off-by: Willy Sudiarto Raharjo <willysr@slackbuilds.org>
This commit is contained in:
B. Watson 2024-03-15 06:49:43 +07:00 committed by Willy Sudiarto Raharjo
parent 84b2ef7615
commit d1baf71613
No known key found for this signature in database
GPG key ID: 3F617144D7238786
6 changed files with 217 additions and 0 deletions

View file

@ -0,0 +1,6 @@
renameutils (programs to make renaming of files easier)
The file renaming utilities (renameutils for short) are a set
of programs designed to make renaming of files faster and less
cumbersome. The file renaming utilities consists of five programs:
qmv, qcp, imv, icp and deurlname.

View file

@ -0,0 +1,27 @@
Description: Fix typo in install target of Makefile
Forwarded: emailed
Author: Francois Marier <francois@debian.org>
Last-Update: 2012-05-06
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -49,7 +49,7 @@ all-local:
@[ -f icp ] || (echo $(LN_S) icmd icp ; $(LN_S) icmd icp)
install-exec-local:
- $(mkdir_p) $(DESTDIR)($bindir)
+ $(mkdir_p) $(DESTDIR)$(bindir)
@[ -f $(DESTDIR)$(bindir)/qmv ] || (echo $(LN_S) qcmd $(DESTDIR)$(bindir)/qmv ; $(LN_S) qcmd $(DESTDIR)$(bindir)/qmv)
@[ -f $(DESTDIR)$(bindir)/qcp ] || (echo $(LN_S) qcmd $(DESTDIR)$(bindir)/qcp ; $(LN_S) qcmd $(DESTDIR)$(bindir)/qcp)
@[ -f $(DESTDIR)$(bindir)/imv ] || (echo $(LN_S) icmd $(DESTDIR)$(bindir)/imv ; $(LN_S) icmd $(DESTDIR)$(bindir)/imv)
--- a/src/Makefile.in
+++ b/src/Makefile.in
@@ -1577,7 +1577,7 @@ all-local:
@[ -f icp ] || (echo $(LN_S) icmd icp ; $(LN_S) icmd icp)
install-exec-local:
- $(mkdir_p) $(DESTDIR)($bindir)
+ $(mkdir_p) $(DESTDIR)$(bindir)
@[ -f $(DESTDIR)$(bindir)/qmv ] || (echo $(LN_S) qcmd $(DESTDIR)$(bindir)/qmv ; $(LN_S) qcmd $(DESTDIR)$(bindir)/qmv)
@[ -f $(DESTDIR)$(bindir)/qcp ] || (echo $(LN_S) qcmd $(DESTDIR)$(bindir)/qcp ; $(LN_S) qcmd $(DESTDIR)$(bindir)/qcp)
@[ -f $(DESTDIR)$(bindir)/imv ] || (echo $(LN_S) icmd $(DESTDIR)$(bindir)/imv ; $(LN_S) icmd $(DESTDIR)$(bindir)/imv)

View file

@ -0,0 +1,64 @@
Description: Fix typo in error message
Forwarded: emailed
Author: Francois Marier <francois@debian.org>
Last-Update: 2018-05-10
--- a/po/fr.po
+++ b/po/fr.po
@@ -722,7 +722,7 @@ msgstr "Variable accessible en écriture seulement\n"
#: src/common/error.c:104
#, c-format
msgid ""
-"An internal error has occured. Please report this error by sending the\n"
+"An internal error has occurred. Please report this error by sending the\n"
"output below to %s.\n"
"\n"
"Program: %s\n"
diff --git a/po/renameutils.pot b/po/renameutils.pot
index 9c0c9c5..c3e3ea4 100644
--- a/po/renameutils.pot
+++ b/po/renameutils.pot
@@ -581,7 +581,7 @@ msgstr ""
#: src/common/error.c:104
#, c-format
msgid ""
-"An internal error has occured. Please report this error by sending the\n"
+"An internal error has occurred. Please report this error by sending the\n"
"output below to %s.\n"
"\n"
"Program: %s\n"
diff --git a/po/sv.po b/po/sv.po
index e44f1f8..784c410 100644
--- a/po/sv.po
+++ b/po/sv.po
@@ -705,7 +705,7 @@ msgstr "Skriv-enbart-variabel\n"
#: src/common/error.c:104
#, c-format
msgid ""
-"An internal error has occured. Please report this error by sending the\n"
+"An internal error has occurred. Please report this error by sending the\n"
"output below to %s.\n"
"\n"
"Program: %s\n"
diff --git a/src/common/error.c b/src/common/error.c
index 72ac9b5..d6544e3 100644
--- a/src/common/error.c
+++ b/src/common/error.c
@@ -87,7 +87,7 @@ free_error(void)
/**
* This function should be called when an internal error has
* occured. It will display a more verbose message, asking
* the user to mail the program author.
*
* @param msg
@@ -102,7 +102,7 @@ internal_error(const char *msg, ...)
if (program_termination_hook != NULL)
program_termination_hook();
fprintf(stderr, _("\
-An internal error has occured. Please report this error by sending the\n\
+An internal error has occurred. Please report this error by sending the\n\
output below to %s.\n\
\n\
Program: %s\n\

View file

@ -0,0 +1,91 @@
#!/bin/bash
# Slackware build script for renameutils
# Written by B. Watson (urchlay@slackware.uk)
# Licensed under the WTFPL. See http://www.wtfpl.net/txt/copying/ for details.
cd $(dirname $0) ; CWD=$(pwd)
PRGNAM=renameutils
VERSION=${VERSION:-0.12.0}
BUILD=${BUILD:-1}
TAG=${TAG:-_SBo}
PKGTYPE=${PKGTYPE:-tgz}
if [ -z "$ARCH" ]; then
case "$( uname -m )" in
i?86) ARCH=i586 ;;
arm*) ARCH=arm ;;
*) ARCH=$( uname -m ) ;;
esac
fi
if [ ! -z "${PRINT_PACKAGE_NAME}" ]; then
echo "$PRGNAM-$VERSION-$ARCH-$BUILD$TAG.$PKGTYPE"
exit 0
fi
TMP=${TMP:-/tmp/SBo}
PKG=$TMP/package-$PRGNAM
OUTPUT=${OUTPUT:-/tmp}
if [ "$ARCH" = "i586" ]; then
SLKCFLAGS="-O2 -march=i586 -mtune=i686"
LIBDIRSUFFIX=""
elif [ "$ARCH" = "i686" ]; then
SLKCFLAGS="-O2 -march=i686 -mtune=i686"
LIBDIRSUFFIX=""
elif [ "$ARCH" = "x86_64" ]; then
SLKCFLAGS="-O2 -fPIC"
LIBDIRSUFFIX="64"
else
SLKCFLAGS="-O2"
LIBDIRSUFFIX=""
fi
set -e
rm -rf $PKG
mkdir -p $TMP $PKG $OUTPUT
cd $TMP
rm -rf $PRGNAM-$VERSION
tar xvf $CWD/$PRGNAM-$VERSION.tar.gz
cd $PRGNAM-$VERSION
chown -R root:root .
find -L . -perm /111 -a \! -perm 755 -a -exec chmod 755 {} + -o \
\! -perm /111 -a \! -perm 644 -a -exec chmod 644 {} +
# Patches from Debian, with thanks. These came from their 0.12.0-11.
patch -p1 < $CWD/patches/install-exec-local-fix.patch
patch -p1 < $CWD/patches/typo_fix.patch
CFLAGS="$SLKCFLAGS" \
CXXFLAGS="$SLKCFLAGS" \
./configure \
--prefix=/usr \
--libdir=/usr/lib${LIBDIRSUFFIX} \
--sysconfdir=/etc \
--localstatedir=/var \
--mandir=/usr/man \
--docdir=/usr/doc/$PRGNAM-$VERSION \
--build=$ARCH-slackware-linux
make
make install-strip DESTDIR=$PKG
# Really do need the cumbersome template code, there are symlinked man pages.
find $PKG/usr/man -type f -exec gzip -9 {} +
for i in $( find $PKG/usr/man -type l ) ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
PKGDOC=$PKG/usr/doc/$PRGNAM-$VERSION
mkdir -p $PKGDOC
cp -a AUTHORS COPYING ChangeLog NEWS README TODO $PKGDOC
cat $CWD/$PRGNAM.SlackBuild > $PKGDOC/$PRGNAM.SlackBuild
mkdir -p $PKG/install
cat $CWD/slack-desc > $PKG/install/slack-desc
cd $PKG
/sbin/makepkg -l y -c n $OUTPUT/$PRGNAM-$VERSION-$ARCH-$BUILD$TAG.$PKGTYPE

View file

@ -0,0 +1,10 @@
PRGNAM="renameutils"
VERSION="0.12.0"
HOMEPAGE="https://www.nongnu.org/renameutils/"
DOWNLOAD="http://download.savannah.gnu.org/releases/renameutils/renameutils-0.12.0.tar.gz"
MD5SUM="a859898a25589e3b19ac8f78ddabb606"
DOWNLOAD_x86_64=""
MD5SUM_x86_64=""
REQUIRES=""
MAINTAINER="B. Watson"
EMAIL="urchlay@slackware.uk"

View file

@ -0,0 +1,19 @@
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.
# Line up the first '|' above the ':' following the base package name, and
@@ -87,7 +87,7 @@ free_error(void)
/**
* This function should be called when an internal error has
- * occured. It will display a more verbose message, asking
+ * occurred. It will display a more verbose message, asking
* the user to mail the program author.
*
# the '|' on the right side marks the last column you can put a character in.
# You must make exactly 11 lines for the formatting to be correct. It's also
# customary to leave one space after the ':' except on otherwise blank lines.
|-----handy-ruler------------------------------------------------------|
renameutils: renameutils (programs to make renaming of files easier)
renameutils:
renameutils: The file renaming utilities (renameutils for short) are a set
renameutils: of programs designed to make renaming of files faster and less
renameutils: cumbersome. The file renaming utilities consists of five programs:
renameutils: qmv, qcp, imv, icp and deurlname.
renameutils:
renameutils:
renameutils:
renameutils:
renameutils: